referrerpolicy=no-referrer-when-downgrade

remove_last_timestamp

Function remove_last_timestamp 

pub fn remove_last_timestamp<T: RemoveLastTimestamp>() -> Weight
Remove the LastTimestamp storage value.

This storage value was removed and replaced by CurrentSlot. As we only remove this storage value, it is safe to call this method multiple times.

This migration requires a type T that implements RemoveLastTimestamp.